.. bayesianbandits documentation master file, created by
   sphinx-quickstart on Fri Feb 24 11:39:20 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bayesianbandits's documentation!
===========================================

`bayesianbandits` is a Python package for Bayesian bandits. It provides a
simple, Pythonic interface to implement and different algorithms to solve multi-armed
bandit problems. To facilitate this, it provides a number of different Bayesian and 
recursive Bayesian estimators to represent the knowledge of the reward distribution
of each arm.

If you have any questions or suggestions, please feel free to open an issue
on the project page on GitHub or contact me at <rishi@kulkarni.science>.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   usage


API Reference
=============

.. autosummary::
   :toctree: generated/

   bayesianbandits.api
   bayesianbandits


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
